==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/DescribeNatGatewaysRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  NatGatewayId,
  DescribeNatGatewaysMaxResults
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeNatGatewaysRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    filter: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[DescribeNatGatewaysMaxResults] = Optional.Absent,
    natGatewayIds: Optional[Iterable[NatGatewayId]] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest = {
    import DescribeNatGatewaysRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(
        filter.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filter)
      .optionallyWith(
        maxResults.map(value =>
          DescribeNatGatewaysMaxResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .optionallyWith(
        natGatewayIds.map(value =>
          value.map { item =>
            NatGatewayId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.natGatewayIds)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeNatGatewaysRequest.ReadOnly =
    zio.aws.ec2.model.DescribeNatGatewaysRequest.wrap(buildAwsValue())
}
object DescribeNatGatewaysRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeNatGatewaysRequest =
      zio.aws.ec2.model.DescribeNatGatewaysRequest(
        dryRun.map(value => value),
        filter.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        natGatewayIds.map(value => value),
        nextToken.map(value => value)
      )
    def dryRun: Optional[Boolean]
    def filter: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[DescribeNatGatewaysMaxResults]
    def natGatewayIds: Optional[List[NatGatewayId]]
    def nextToken: Optional[String]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getFilter: ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filter", filter)
    def getMaxResults: ZIO[Any, AwsError, DescribeNatGatewaysMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNatGatewayIds: ZIO[Any, AwsError, List[NatGatewayId]] =
      AwsError.unwrapOptionField("natGatewayIds", natGatewayIds)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest
  ) extends zio.aws.ec2.model.DescribeNatGatewaysRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val filter: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filter())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[DescribeNatGatewaysMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ec2.model.primitives.DescribeNatGatewaysMaxResults(value)
        )
    override val natGatewayIds: Optional[List[NatGatewayId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.natGatewayIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives.NatGatewayId(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest
  ): zio.aws.ec2.model.DescribeNatGatewaysRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.130.5-sources.jar: zio/aws/ec2/model/DescribeNatGatewaysRequest.scala <==
package zio.aws.ec2.model
import java.lang.Integer
import zio.aws.ec2.model.primitives.{
  NatGatewayId,
  DescribeNatGatewaysMaxResults
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeNatGatewaysRequest(
    filter: Option[Iterable[zio.aws.ec2.model.Filter]] = None,
    maxResults: Option[DescribeNatGatewaysMaxResults] = None,
    natGatewayIds: Option[Iterable[NatGatewayId]] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest = {
    import DescribeNatGatewaysRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest
      .builder()
      .optionallyWith(
        filter.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filter)
      .optionallyWith(
        maxResults.map(value =>
          DescribeNatGatewaysMaxResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .optionallyWith(
        natGatewayIds.map(value =>
          value.map { item =>
            NatGatewayId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.natGatewayIds)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeNatGatewaysRequest.ReadOnly =
    zio.aws.ec2.model.DescribeNatGatewaysRequest.wrap(buildAwsValue())
}
object DescribeNatGatewaysRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeNatGatewaysRequest =
      zio.aws.ec2.model.DescribeNatGatewaysRequest(
        filter.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        natGatewayIds.map(value => value),
        nextToken.map(value => value)
      )
    def filter: Option[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Option[DescribeNatGatewaysMaxResults]
    def natGatewayIds: Option[List[NatGatewayId]]
    def nextToken: Option[String]
    def getFilter: ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filter", filter)
    def getMaxResults: ZIO[Any, AwsError, DescribeNatGatewaysMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNatGatewayIds: ZIO[Any, AwsError, List[NatGatewayId]] =
      AwsError.unwrapOptionField("natGatewayIds", natGatewayIds)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest
  ) extends zio.aws.ec2.model.DescribeNatGatewaysRequest.ReadOnly {
    override val filter: Option[List[zio.aws.ec2.model.Filter.ReadOnly]] = scala
      .Option(impl.filter())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Filter.wrap(item)
        }.toList
      )
    override val maxResults: Option[DescribeNatGatewaysMaxResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.ec2.model.primitives.DescribeNatGatewaysMaxResults(value)
      )
    override val natGatewayIds: Option[List[NatGatewayId]] = scala
      .Option(impl.natGatewayIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.NatGatewayId(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeNatGatewaysRequest
  ): zio.aws.ec2.model.DescribeNatGatewaysRequest.ReadOnly = new Wrapper(impl)
}
